@@ -5,7 +5,7 @@ use warnings;
 package Kavorka::Multi;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.005';
+our $VERSION   = '0.006';
 
 use Devel::Pragma qw( fqname );
 use Parse::Keyword {};
@@ -94,7 +94,8 @@ my $DISPATCH = sub
 	else
 	{
 		require mro;
-		@candidates = map @{$DISPATCH_TABLE{$_}{$subname} || [] }, @{ $pkg->mro::get_linear_isa };
+		my $invocant = ref($_[0]) || $_[0];
+		@candidates  = map @{$DISPATCH_TABLE{$_}{$subname} || [] }, @{ $invocant->mro::get_linear_isa };
 	}
 	
 	for my $c (@candidates)
